durationtools.numeric_seconds_to_escaped_clock_string
=====================================================

.. autofunction:: abjad.tools.durationtools.numeric_seconds_to_escaped_clock_string.numeric_seconds_to_escaped_clock_string
